# auto-sklearn

auto-sklearn is an automated machine learning toolkit and a drop-in replacement for a scikit-learn estimator.

Find the documentation [here](http://automl.github.io/auto-sklearn/)

Status for master branch:

[![Build Status](https://travis-ci.org/automl/auto-sklearn.svg?branch=master)](https://travis-ci.org/automl/auto-sklearn)
[![Code Health](https://landscape.io/github/automl/auto-sklearn/master/landscape.png)](https://landscape.io/github/automl/auto-sklearn/master)
[![codecov](https://codecov.io/gh/automl/auto-sklearn/branch/master/graph/badge.svg)](https://codecov.io/gh/automl/auto-sklearn)

Status for development branch

[![Build Status](https://travis-ci.org/automl/auto-sklearn.svg?branch=development)](https://travis-ci.org/automl/auto-sklearn)
[![Code Health](https://landscape.io/github/automl/auto-sklearn/development/landscape.png)](https://landscape.io/github/automl/auto-sklearn/development)
[![codecov](https://codecov.io/gh/automl/auto-sklearn/branch/development/graph/badge.svg)](https://codecov.io/gh/automl/auto-sklearn)
